# easy_coloc
Project ocean model gridded fields onto observation space

[![Build Status](https://travis-ci.org/raphaeldussin/easy_coloc.svg?branch=master)](https://travis-ci.org/raphaeldussin/easy_coloc)

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/raphaeldussin/easy_coloc/master)
